flutter_password_input library

Classes

PasswordTextField
A password text field widget that detects Caps Lock state and displays a customizable warning message when Caps Lock is enabled.
PasswordTextFieldTheme
A theme class that defines the visual styling for PasswordTextField.
WarningTooltipTheme
A theme class that defines the visual styling for warning tooltips.

Enums

PasswordFieldStatus
Represents the current status of the password field.
TooltipAlignment
The alignment of the tooltip along the cross-axis of the direction.
TooltipAnimation
The animation type used when showing and hiding the tooltip.
TooltipDirection
The direction in which the tooltip appears relative to the child widget.
WarningAlignment
Alignment options for warning messages displayed around the text field.
WarningDisplayMode
Controls how warning messages (Caps Lock, paste) are displayed.

Typedefs

PasswordFieldWidgetBuilder = Widget Function(BuildContext context, PasswordFieldStatus status)
Builder typedef for prefix/suffix widgets that receive the current field status.