WarningDisplayMode enum
Controls how warning messages (Caps Lock, paste) are displayed.
Values
- message → const WarningDisplayMode
-
Warnings appear as inline text messages above or below the text field.
- tooltip → const WarningDisplayMode
-
Warnings appear inside a tooltip anchored to the text field.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
WarningDisplayMode> - A constant List of the values in this enum, in order of their declaration.